@@ -6,15 +6,37 @@
 #' @return The calculated AIC, AICc, and BIC for the parameters of the fitted model.
 #'
 #' @examples
-#' \dontrun{
-#' res <- HeckmanEM(y, x, w, cc, nu = 4, family = "Normal", error = 1e-05, iter.max = 500, 
+#' \donttest{
+#' n <- 100
+#' family <- "T"
+#' nu <- 4
+#' rho <- .6
+#' cens <- .25
+#'
+#' set.seed(20200527)
+#' w <- cbind(1,runif(n,-1,1),rnorm(n))
+#' x <- cbind(w[,1:2])
+#' c <- qt(cens, df=nu)
+#'
+#' sigma2 <- 1
+#'
+#' beta <- c(1,0.5)
+#' gamma <- c(1,0.3,-.5)
+#' gamma[1] <- -c*sqrt(sigma2)
+#'
+#' set.seed(1)
+#' datas <- rHeckman(x,w,beta,gamma,sigma2,rho,nu,family=family)
+#' y <- datas$y
+#' cc <- datas$cc
+#'
+#' res <- HeckmanEM(y, x, w, cc, nu = 4, family = "Normal", error = 1e-05, iter.max = 500,
 #'                  im = TRUE, criteria = FALSE)
 #' cr <- HeckmanEM.criteria(res)
 #' }
 #' @export
 HeckmanEM.criteria <- function(obj){
 
-  if(class(obj) != "HeckmanEM") stop("Only \"HeckmanEM\" objects accepted!")
+  if(!inherits(obj,"HeckmanEM")) stop("Only \"HeckmanEM\" objects accepted!")
   if (obj$family != "Normal" && obj$family !="normal" && obj$family !="T" && obj$family !="t" ) stop("Family not recognized")
 
   n <- length(obj$y)
